@@ -32,11 +32,9 @@ struct _PulseDeviceSwitchPrivate
     GList *profiles;
 };
 
-static void pulse_device_switch_class_init   (PulseDeviceSwitchClass *klass);
-static void pulse_device_switch_init         (PulseDeviceSwitch      *swtch);
 static void pulse_device_switch_dispose      (GObject                *object);
 
-G_DEFINE_TYPE (PulseDeviceSwitch, pulse_device_switch, MATE_MIXER_TYPE_DEVICE_SWITCH)
+G_DEFINE_TYPE_WITH_PRIVATE (PulseDeviceSwitch, pulse_device_switch, MATE_MIXER_TYPE_DEVICE_SWITCH)
 
 static gboolean     pulse_device_switch_set_active_option (MateMixerSwitch       *mms,
                                                            MateMixerSwitchOption *mmso);
@@ -60,16 +58,12 @@ pulse_device_switch_class_init (PulseDeviceSwitchClass *klass)
     switch_class = MATE_MIXER_SWITCH_CLASS (klass);
     switch_class->set_active_option = pulse_device_switch_set_active_option;
     switch_class->list_options      = pulse_device_switch_list_options;
-
-    g_type_class_add_private (G_OBJECT_CLASS (klass), sizeof (PulseDeviceSwitchPrivate));
 }
 
 static void
 pulse_device_switch_init (PulseDeviceSwitch *swtch)
 {
-    swtch->priv = G_TYPE_INSTANCE_GET_PRIVATE (swtch,
-                                               PULSE_TYPE_DEVICE_SWITCH,
-                                               PulseDeviceSwitchPrivate);
+    swtch->priv = pulse_device_switch_get_instance_private (swtch);
 }
 
 static void
@@ -132,7 +126,7 @@ pulse_device_switch_set_active_profile_by_name (PulseDeviceSwitch *swtch, const
     g_return_if_fail (name != NULL);
 
     item = g_list_find_custom (swtch->priv->profiles, name, compare_profile_name);
-    if G_UNLIKELY (item == NULL) {
+    if (G_UNLIKELY (item == NULL)) {
         g_debug ("Invalid device switch profile name %s", name);
         return;
     }
@@ -150,7 +144,7 @@ pulse_device_switch_set_active_option (MateMixerSwitch *mms, MateMixerSwitchOpti
     g_return_val_if_fail (PULSE_IS_DEVICE_PROFILE (mmso), FALSE);
 
     device = mate_mixer_device_switch_get_device (MATE_MIXER_DEVICE_SWITCH (mms));
-    if G_UNLIKELY (device == NULL)
+    if (G_UNLIKELY (device == NULL))
         return FALSE;
 
     device_name  = mate_mixer_device_get_name (device);
